<?php

namespace Drupal\phone_verification;

interface PhoneVerificationInterface {

  /**
   * Returns available code types.
   *
   * @return array
   *   An array of code type names keyed by code type key
   */
  public function getCodeTypes();

  /**
   * Helper function to check if number is verified
   *
   * This process makes sure that user won't need to verify
   * phone number multiple times during period of its validity
   *
   * @param string $telephone_number
   * @return bool
   */
  public function isVerifiedNumber($telephone_number);

  /**
   * Generates a verification code.
   *
   * @param int $code_length
   * @param int $code_type
   *
   * @return string
   */
  public function generateCode($code_length = NULL, $code_type = NULL);

  /**
   * @param string $telephone_number
   * @param string $code
   * @param string $message_text
   *
   * @return \Drupal\sms\Message\SmsMessageResult|null
   *   The result associated with this SMS message, or NULL if there is no
   *   result.
   */
  public function sendVerificationCode($telephone_number, $code, $message_text = '');

  /**
   * @param $telephone_number
   * @param $code
   *
   * @return bool
   *   TRUE if verification was successful, FALSE otherwise
   */
  public function verifyCode($telephone_number, $code);
}
